# Donations
It takes me a long time to make these libraries. If you would like to support my work, Then you can follow my patreon :)

https://www.patreon.com/Schkimansky

# Library
This is a reliable, Python GUI Library.

```python
import trilent
# Example coming soon since library has no documentation nor any code.
```

# Installation
```bash
pip install trilent
```

# Documentation
Library is in planning stage

